=================
**Django Tag Me**
=================

|

**Version = 2025.12.05.2**

|

*Django Tag Me... Tag a model, a field, user tags and more...*

|

.. image:: https://github.com/imAsparky/django-tag-me/actions/workflows/main_PR.yaml/badge.svg
   :alt: Tests
   :target: https://github.com/imAsparky/django-tag-me/actions/workflows/main_PR.yaml

.. image:: https://img.shields.io/badge/dynamic/toml?url=https%3A%2F%2Fraw.githubusercontent.com%2FimAsparky%2Fdjango-tag-me%2Fmain%2Fpyproject.toml&query=project.dependencies&logo=Django&label=Versions&labelColor=%23092E20
   :alt: Django Version Badge
   :target: https://docs.djangoproject.com/en/4.2/

.. image:: https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2FimAsparky%2Fdjango-tag-me%2Fmain%2Fpyproject.toml&logo=Python
   :alt: Python Version Badge
   :target: https://devdocs.io/python~3.10/

.. image:: https://www.repostatus.org/badges/latest/wip.svg
   :alt: Project Status: WIP – Initial development is in progress, but there has not yet been a stable, usable release suitable for the public.
   :target: https://www.repostatus.org/#wip

.. image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit

.. image:: https://readthedocs.org/projects/django-tag-me/badge/?version=latest
   :target: https://django-tag-me.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

|

`django-tag-me`, a simple approach for `Django` tagging.

|

Features in the Pipeline
------------------------

|

#. Easily set up `User tags`. **In Progress**
#. Tag a field. **Completed**
#. Tag a model. **Completed**
#. Easy as `1,2,3` - Custom select widget integration in your forms and templates. **Completed**
#. `sqLite` search with `i_contains`
#. `Postgres` text search or `i_contains`

|

Tag Selection Interface!
------------------------

|

**Dropdown with selection options.**

|

.. image:: https://raw.githubusercontent.com/imAsparky/django-tag-me/main/docs/source/imgs/tag_dropdown_with_options.png
   :alt: Tag dropdown with options

|

**Dropdown tag options search functionality.**

|

.. image:: https://raw.githubusercontent.com/imAsparky/django-tag-me/main/docs/source/imgs/tag_dropdown_search.png
   :alt: Tag dropdown search functionality

|

Credits
-------

|

- Dropdown interface adapted from `alpinejs-multiselect <https://github.com/alexpechkarev/alpinejs-multiselect/>`_
- Built with `Django Cookiecutter <https://github.com/imAsparky/django-cookiecutter>`_